==> react-native-cometchat-calling-component-1.1.13.tgz: package/components/HangUpButton.js <==
import React, {Component} from 'react';
import { View, TouchableOpacity, Image,NativeEventEmitter,PixelRatio } from 'react-native';
import JitsiManager from '../lib/JitsiManager';
import { connect } from 'react-redux';
import AudioMode from '../AudioMode'
import Logger from 'react-native-cometchat-calling-component/lib/Logger';

class HangUpButton extends Component{

    constructor() {
        super();
        this.eventEmitter = new NativeEventEmitter(AudioMode);
        this.handleEmit = this.handleEmit.bind(this);
    }

    onHangUp(){
        this.props.onHangUp();
        this.handleEmit();
    }

    handleEmit() {
        console.log("CallEvent Emitted")
        this.eventEmitter.emit('CallEvent', { type: 'EndCall' });
    }

    renderHangUpIcon(){
        return <TouchableOpacity onPress={()=>this.onHangUp()}><Image style={this.style.lt_control_icon} source={require('../icons/icon_hangup.png')}/></TouchableOpacity>;    
    }

    render(){
        return(
            <View style={this.style.lt_control_view}>
                { this.renderHangUpIcon() }
            </View> 
        )
    }

    style = {
        lt_control_icon: { width: 25, height: 25 },
        lt_control_view: { width: 55, height: 55, margin: 5, backgroundColor: '#ec4c3a', borderRadius: 50, alignItems: 'center', justifyContent:'center' }
    };
    
}
  
function mapDispatchToProps (dispatch) {
    return {
        onHangUp: () => JitsiManager.onHangUp()
    }
}

export default connect(null, mapDispatchToProps)(HangUpButton)

==> react-native-cometchat-calling-component-1.3.0.tgz: package/components/HangUpButton.js <==
import React, {Component} from 'react';
import { View, TouchableOpacity, Image,NativeEventEmitter,PixelRatio } from 'react-native';
import JitsiManager from '../lib/JitsiManager';
import { connect } from 'react-redux';
import AudioMode from '../AudioMode'
import Logger from 'react-native-cometchat-calling-component/lib/Logger';

class HangUpButton extends Component{

    constructor() {
        super();
        this.eventEmitter = new NativeEventEmitter(AudioMode);
        this.handleEmit = this.handleEmit.bind(this);
    }

    onHangUp(){
        this.props.onHangUp();
        this.handleEmit();
    }

    handleEmit() {
        console.log("CallEvent Emitted")
        this.eventEmitter.emit('CallEvent', { type: 'EndCallButtonPressed' });
    }

    renderHangUpIcon(){
        return <TouchableOpacity onPress={()=>this.onHangUp()}><Image style={this.style.lt_control_icon} source={require('../icons/icon_hangup.png')}/></TouchableOpacity>;    
    }

    render(){
        return(
            <View style={this.style.lt_control_view}>
                { this.renderHangUpIcon() }
            </View> 
        )
    }

    style = {
        lt_control_icon: { width: 25, height: 25 },
        lt_control_view: { width: 55, height: 55, margin: 5, backgroundColor: '#ec4c3a', borderRadius: 50, alignItems: 'center', justifyContent:'center' }
    };
    
}
  
function mapDispatchToProps (dispatch) {
    return {
        onHangUp: () => JitsiManager.onHangUp()
    }
}

export default connect(null, mapDispatchToProps)(HangUpButton)
